@@ -110,8 +110,8 @@ vdir_insert (GsfZipVDir *vdir, char const * name, GsfZipDirent *dirent)
 		dirname = g_strndup (name, (gsize) (p - name));
 		child = vdir_child_by_name (vdir, dirname);
 		if (!child) {
-			child = gsf_vdir_new (dirname, TRUE, NULL);
-			gsf_vdir_add_child (vdir, child);
+			child = gsf_zip_vdir_new (dirname, TRUE, NULL);
+			gsf_zip_vdir_add_child (vdir, child);
 		}
 		g_free (dirname);
 		if (*(p+1) != '\0') {
@@ -119,8 +119,8 @@ vdir_insert (GsfZipVDir *vdir, char const * name, GsfZipDirent *dirent)
 			vdir_insert (child, name, dirent);
 		}
 	} else { /* A simple file name */
-		child = gsf_vdir_new (name, FALSE, dirent);
-		gsf_vdir_add_child (vdir, child);
+		child = gsf_zip_vdir_new (name, FALSE, dirent);
+		gsf_zip_vdir_add_child (vdir, child);
 	}
 }
 
@@ -254,7 +254,7 @@ zip_info_unref (ZipInfo *info)
 	if (info->ref_count-- != 1)
 		return;
 
-	gsf_vdir_free (info->vdir, FALSE);
+	gsf_zip_vdir_free (info->vdir, FALSE);
 	for (p = info->dirent_list; p != NULL; p = p->next)
 		gsf_zip_dirent_free ((GsfZipDirent *) p->data);
 
@@ -353,7 +353,7 @@ zip_build_vdirs (GsfInfileZip *zip)
 	GsfZipDirent *dirent;
 	ZipInfo *info = zip->info;
 
-	info->vdir = gsf_vdir_new ("", TRUE, NULL);
+	info->vdir = gsf_zip_vdir_new ("", TRUE, NULL);
 	for (l = info->dirent_list; l; l = l->next) {
 		dirent = (GsfZipDirent *) l->data;
 		vdir_insert (info->vdir, dirent->name, dirent);
@@ -857,7 +857,7 @@ GSF_CLASS (GsfInfileZip, gsf_infile_zip,
 	   GSF_INFILE_TYPE)
 
 /**
- * gsf_infile_zip_new :
+ * gsf_infile_zip_new:
  * @source: A base #GsfInput
  * @err: A #GError, optionally %null
  *
