@@ -44,19 +44,61 @@ typedef struct {
 	GType            typ;
 } GsfOOMetaIn;
 
-G_MODULE_EXPORT char const *
+/**
+ * gsf_odf_get_version_string:
+ * Gives the ODF version used by libgsf when writing Open Document files.
+ *
+ * Since: 1.14.24
+ *
+ * Returns: the ODF version as a string: "1.2".
+ **/
+char const *
+gsf_odf_get_version_string (void)
+{
+	return "1.2";
+}
+
+/**
+ * get_gsf_odf_version_string: (skip)
+ * Gives the ODF version used by libgsf when writing Open Document files.
+ *
+ * Deprecated: 1.14.24, use gsf_odf_get_version_string
+ *
+ * Returns: the ODF version as a string: "1.2".
+ **/
+char const *
 get_gsf_odf_version_string (void)
 {
 	return "1.2";
 }
 
-G_MODULE_EXPORT short
-get_gsf_odf_version (void)
+/**
+ * gsf_odf_get_version:
+ * Gives the ODF version used by libgsf when writing Open Document files.
+ *
+ * Since: 1.14.24
+ *
+ * Returns: the ODF version: 102.
+ **/
+short
+gsf_odf_get_version (void)
 {
 	return 102;
 }
 
-
+/**
+ * get_gsf_odf_version: (skip)
+ * Gives the ODF version used by libgsf when writing Open Document files.
+ *
+ * Deprecated: 1.14.24, use gsf_odf_get_version
+ *
+ * Returns: the ODF version: 102.
+ **/
+short
+get_gsf_odf_version (void)
+{
+	return 102;
+}
 
 /* Generated based on:
  * http://www.oasis-open.org/committees/download.php/12572/OpenDocument-v1.0-os.pdf */
@@ -146,7 +188,28 @@ GsfXMLInNS gsf_ooo_ns[] = {
 	{ NULL, 0 }
 };
 
-G_MODULE_EXPORT GsfXMLInNS *get_gsf_ooo_ns (void)
+/**
+ * gsf_odf_get_ns:
+ *
+ * Since: 1.14.24
+ *
+ * Returns: the used ODF namespace
+ **/
+GsfXMLInNS const *
+gsf_odf_get_ns (void)
+{
+	return gsf_ooo_ns;
+}
+
+/**
+ * get_gsf_ooo_ns: (skip)
+ *
+ * Deprecated: 1.14.24, use gsf_odf_get_ns
+ *
+ * Returns: the used ODF namespace
+ **/
+GsfXMLInNS *
+get_gsf_ooo_ns (void)
 {
 	return gsf_ooo_ns;
 }
@@ -264,7 +327,7 @@ od_meta_user_defined_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 			if (g_str_has_prefix (mi->name, "GSF_DOCPROP_VECTOR:")) {
 				gchar *true_name = strchr (mi->name + 19, ':');
 				if (true_name != NULL && *(++true_name) != 0) {
-					GsfDocProp *prop = gsf_doc_meta_data_lookup 
+					GsfDocProp *prop = gsf_doc_meta_data_lookup
 						(mi->md, true_name);
 					if (prop == NULL) {
 						GsfDocPropVector *vector = gsf_docprop_vector_new ();
@@ -286,13 +349,13 @@ od_meta_user_defined_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 							vector = gsf_value_get_docprop_varray (new);
 							g_value_array_append (vector, res);
 							gsf_doc_prop_set_val (prop, new);
-						} else 
+						} else
 							g_printerr (_("Property \"%s\" used for "
 								      "multiple types!"), true_name);
 						g_value_unset (res);
-						g_free (res);						
+						g_free (res);
 					}
-				
+
 					g_free (mi->name);
 					mi->name = NULL;
 					return;
@@ -362,14 +425,16 @@ gsf_opendoc_metadata_subtree_free (G_GNUC_UNUSED GsfXMLIn *xin, gpointer old_sta
 static GsfXMLInDoc *doc_subtree = NULL;
 
 /**
- * gsf_opendoc_metadata_subtree :
- * @doc : #GsfXMLInDoc
- * @md  : #GsfDocMetaData
+ * gsf_doc_meta_data_odf_subtree:
+ * @md: #GsfDocMetaData
+ * @doc: #GsfXMLInDoc
  *
  * Extend @xin so that it can parse a subtree in OpenDoc metadata format
+ *
+ * Since: 1.14.24
  **/
 void
-gsf_opendoc_metadata_subtree (GsfXMLIn *xin, GsfDocMetaData *md)
+gsf_doc_meta_data_odf_subtree (GsfDocMetaData *md, GsfXMLIn *doc)
 {
 	GsfOOMetaIn *state = NULL;
 
@@ -382,12 +447,27 @@ gsf_opendoc_metadata_subtree (GsfXMLIn *xin, GsfDocMetaData *md)
 	state->md = md;
 	state->typ = G_TYPE_NONE;
 	g_object_ref (md);
-	gsf_xml_in_push_state (xin, doc_subtree, state, gsf_opendoc_metadata_subtree_free, NULL);
+	gsf_xml_in_push_state (doc, doc_subtree, state, gsf_opendoc_metadata_subtree_free, NULL);
 }
 
 /**
- * gsf_opendoc_metadata_subtree_internal :
- * @doc : #GsfXMLInDoc
+ * gsf_opendoc_metadata_subtree: (skip)
+ * @doc: #GsfXMLInDoc
+ * @md: #GsfDocMetaData
+ *
+ * Deprecated: 1.14.24, use gsf_doc_meta_data_odf_subtree
+ *
+ * Extend @xin so that it can parse a subtree in OpenDoc metadata format
+ **/
+void
+gsf_opendoc_metadata_subtree (GsfXMLIn *xin, GsfDocMetaData *md)
+{
+	gsf_doc_meta_data_odf_subtree (md, xin);
+}
+
+/**
+ * gsf_opendoc_metadata_subtree_internal:
+ * @doc: #GsfXMLInDoc
  *
  * Extend @xin so that it can parse a subtree in OpenDoc metadata format
  * The current user_state must be a  GsfOOMetaIn!
@@ -408,17 +488,19 @@ static GsfXMLInNode const gsf_opendoc_meta_dtd[] = {
 };
 
 /**
- * gsf_opendoc_metadata_read :
- * @input : #GsfInput
- * @md    : #GsfDocMetaData
+ * gsf_doc_meta_data_read_from_odf:
+ * @md: #GsfDocMetaData
+ * @input: #GsfInput
  *
  * Read an OpenDocument metadata stream from @input and store the properties
  * into @md.  Overwrite any existing properties with the same id.
  *
+ * Since: 1.14.24
+ *
  * Returns: a GError if there is a problem.
  **/
-GError *
-gsf_opendoc_metadata_read (GsfInput *input, GsfDocMetaData *md)
+GError	*
+gsf_doc_meta_data_read_from_odf (GsfDocMetaData *md, GsfInput *input)
 {
 	GsfXMLInDoc	*doc;
 	GsfOOMetaIn	 state;
@@ -444,6 +526,23 @@ gsf_opendoc_metadata_read (GsfInput *input, GsfDocMetaData *md)
 	return state.err;
 }
 
+/**
+ * gsf_opendoc_metadata_read: (skip)
+ * @input: #GsfInput
+ * @md: #GsfDocMetaData
+ *
+ * Read an OpenDocument metadata stream from @input and store the properties
+ * into @md.  Overwrite any existing properties with the same id.
+ *
+ * Deprecated: 1.14.24, use gsf_doc_meta_data_read_from_odf
+ *
+ * Returns: a GError if there is a problem.
+ **/
+GError *
+gsf_opendoc_metadata_read (GsfInput *input, GsfDocMetaData *md)
+{
+	return gsf_doc_meta_data_read_from_odf (md, input);
+}
 
 static char const *
 od_map_prop_name (char const *name)
@@ -517,20 +616,33 @@ meta:object-count
 	GSF_META_NAME_OBJECT_COUNT:
 #endif
 
+/* ODF does not like "t" and "f" which we use normally */
+static void
+gsf_xml_out_add_gvalue_for_odf (GsfXMLOut *xout, char const *id, GValue const *val)
+{
+		if (G_VALUE_TYPE (val) == G_TYPE_BOOLEAN)
+			gsf_xml_out_add_cstr
+				(xout, id,
+				 g_value_get_boolean (val) ? "true" : "false");
+			else
+				gsf_xml_out_add_gvalue (xout, id, val);
+}
+
+
 static void
 meta_write_props_user_defined (char const *prop_name, GValue const *val, GsfXMLOut *output)
 {
 	GType t;
 	char const *type_name = NULL;
-	
+
 	gsf_xml_out_start_element (output, "meta:user-defined");
 	gsf_xml_out_add_cstr (output, "meta:name", prop_name);
-	
+
 	if (NULL == val) {
 			gsf_xml_out_end_element (output);
 			return;
 	}
-	
+
 	t = G_VALUE_TYPE (val);
 	switch (t) {
 	case G_TYPE_CHAR:
@@ -551,7 +663,7 @@ meta_write_props_user_defined (char const *prop_name, GValue const *val, GsfXMLO
 	case G_TYPE_DOUBLE:
 		type_name = "float";
 		break;
-		
+
 	default:
 		if (GSF_TIMESTAMP_TYPE == t)
 			type_name = "date";
@@ -559,7 +671,7 @@ meta_write_props_user_defined (char const *prop_name, GValue const *val, GsfXMLO
 	if (NULL != type_name)
 		gsf_xml_out_add_cstr (output, "meta:value-type", type_name);
 	if (NULL != val)
-		gsf_xml_out_add_gvalue (output, NULL, val);
+		gsf_xml_out_add_gvalue_for_odf (output, NULL, val);
 	gsf_xml_out_end_element (output);
 }
 
@@ -606,9 +718,9 @@ meta_write_props (char const *prop_name, GsfDocProp *prop, GsfXMLOut *output)
 
 			for (i = 0; i < num_values; i++) {
 				GValue	*v;
-				char    *new_name = g_strdup_printf 
+				char    *new_name = g_strdup_printf
 					("GSF_DOCPROP_VECTOR:%.4i:%s", i, prop_name);
-				
+
 				v = g_value_array_get_nth (vector, i);
 				meta_write_props_user_defined (new_name, v, output);
 				g_free (new_name);
@@ -621,12 +733,21 @@ meta_write_props (char const *prop_name, GsfDocProp *prop, GsfXMLOut *output)
 	/* Standardized  ODF meta items*/
 	gsf_xml_out_start_element (output, mapped_name);
 	if (NULL != val)
-		gsf_xml_out_add_gvalue (output, NULL, val);
+		gsf_xml_out_add_gvalue_for_odf (output, NULL, val);
 	gsf_xml_out_end_element (output);
 }
 
+/**
+ * gsf_doc_meta_data_write_to_odf:
+ * @md: #GsfDocMetaData
+ * @output: a pointer to a #GsfOutput.
+ *
+ * Since: 1.14.24
+ *
+ * Returns: TRUE if no error occured.
+ **/
 gboolean
-gsf_opendoc_metadata_write (gpointer output, GsfDocMetaData const *md)
+gsf_doc_meta_data_write_to_odf (GsfDocMetaData const *md, gpointer output)
 {
 	char *ver_str;
 	GsfXMLOut *xout;
@@ -642,7 +763,7 @@ gsf_opendoc_metadata_write (gpointer output, GsfDocMetaData const *md)
 
 	ver_str = oout
 		? gsf_odf_out_get_version_string (oout)
-		: g_strdup (get_gsf_odf_version_string ());
+		: g_strdup (gsf_odf_get_version_string ());
 
 	gsf_xml_out_start_element (xout, OFFICE "document-meta");
 	gsf_xml_out_add_cstr_unchecked (xout, "xmlns:office",
@@ -667,6 +788,21 @@ gsf_opendoc_metadata_write (gpointer output, GsfDocMetaData const *md)
 	return TRUE;
 }
 
+/**
+ * gsf_opendoc_metadata_write: (skip)
+ * @output: a pointer to a #GsfOutput.
+ * @md: #GsfDocMetaData
+ *
+ * Deprecated: 1.14.24, use gsf_doc_meta_data_write_to_odf
+ *
+ * Returns: TRUE if no error occured.
+ **/
+gboolean
+gsf_opendoc_metadata_write (gpointer output, GsfDocMetaData const *md)
+{
+	return gsf_doc_meta_data_write_to_odf (md, output);
+}
+
 /****************************************************************************/
 
 typedef struct _GsfODFOutPrivate {
@@ -745,7 +881,7 @@ gsf_odf_out_class_init (GObjectClass *gobject_class)
 				   G_MAXINT,
 				   100,
 				   GSF_PARAM_STATIC |
-				   G_PARAM_READWRITE | 
+				   G_PARAM_READWRITE |
 				   G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (gobject_class, sizeof (GsfODFOutPrivate));
